import QtQuick 2.2
import QtQuick.Controls 2.0

Item {
    id: root
    property alias text: label.text
    property alias iconSource: icon.source
    property bool isHoverd: false
    property bool isPressed: false
    signal clicked
    activeFocusOnTab: true

    Image {
        id: icon
        anchors {
            top: parent.top
            topMargin: label.contentWidth > 0 ? smallSpacing : smallSpacing /2
            horizontalCenter: parent.horizontalCenter
        }
        fillMode: Image.PreserveAspectFit
    }
    Label {
        id: label
        anchors {
            top: icon.bottom
            topMargin: smallSpacing
            left: parent.left
            right: parent.right
        }
        color: "white"
        visible: contentWidth > 0
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignTop
        wrapMode: Text.WordWrap
    }
    Rectangle{
        id: background
        radius: 10
        color: isHoverd || root.activeFocus ? isPressed ? Qt.rgba(1, 1, 1, 0.1) : Qt.rgba(1, 1, 1, 0.2) : "transparent"
        anchors.fill: parent
    }

    MouseArea {
        id: mouseArea
        anchors.fill: parent
        hoverEnabled: true
        onPressed: {root.clicked(); isPressed = true}
        onReleased: isPressed = false
        onEntered: isHoverd = true
        onExited: isHoverd = false
    }
    Keys.onEnterPressed: clicked()
    Keys.onReturnPressed: clicked()
    Keys.onSpacePressed: clicked()

    Accessible.onPressAction: clicked()
    Accessible.role: Accessible.Button
    Accessible.name: label.text
}
