import QtQuick 2.8
import QtQuick.Layouts 1.2
import QtQuick.Controls 2.1
import QtQuick.Controls.Styles 1.4

Item {
    id: root
    property Item mainPasswordBox: passwordBox
    property Item mainUserBox: userBox
    property string lastUserName
    property bool loginScreenUiVisible: false
    property alias notificationMessage: notificationsLabel.text

    property alias userListModel: userListView.model
    property alias userListCurrentIndex: userListView.currentIndex
    property alias placeholderText: passwordBox.placeholderText
    property alias userPlaceholderText: userBox.placeholderText
    property alias userList: userListView
    property int visibleBoundary: mapFromItem(passwordBox, 0, 0).y
    property bool isOn: false
    property bool isOther: false
    onHeightChanged: visibleBoundary = mapFromItem(passwordBox, 0, 0).y + passwordBox.height + smallSpacing

    signal loginRequest(string username, string password)
    signal messageClear;
    function startLogin() {
        var domainUser = userBox.text + "@zte.intra"
        var username = isOther ? domainUser : userList.selectedUser
        var password = passwordBox.text
        loginRequest(username, password);
    }

    UserList {
        id: userListView
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.verticalCenter
        anchors.bottomMargin: largeSpacing * 3
        visible: !isOther
        Button{
            id: rightArraw
            activeFocusOnTab: true
            anchors.left: userListView.right
            anchors.leftMargin: 70
            anchors.top: parent.top
            anchors.topMargin: 30
            visible: userListModel.count >= userListModel.disableAvatarsThreshold
            width: 26
            height: 40
            background: Image{
                anchors.fill: parent
                source: rightArraw.hovered || leftArraw.activeFocus ?
                            rightArraw.down ? "rightArrawPressed.png" : "rightArrawHover.png" : "rightArraw.png"
                fillMode: Image.PreserveAspectFit
            }
            onClicked: userListView.currentIndex++
        }
        onCurrentIndexChanged: {
            passwordBox.clear()
            passwordBox.forceActiveFocus()
            messageClear()
        }

        Button{
            id: leftArraw
            anchors.right: userListView.left
            anchors.rightMargin: 70
            anchors.top: parent.top
            anchors.topMargin: 30
            visible: userListModel.count >= userListModel.disableAvatarsThreshold
            width: 26
            height: 40
            background: Image{
                anchors.fill: parent
                source: leftArraw.hovered || leftArraw.activeFocus ?
                            leftArraw.down ? "leftArrawPressed.png" : "leftArrawHover.png" : "leftArraw.png"
                fillMode: Image.PreserveAspectFit
            }
            onClicked: userListView.currentIndex--
        }
    }
    TextField {
        id: userBox
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.bottom: parent.verticalCenter
        anchors.bottomMargin: largeSpacing
        visible: isOther
        background: Rectangle{
            color: "white"
            opacity: 0.2
            radius: 4
            implicitWidth: 250
            implicitHeight: 36
            border.color: Qt.rgba(1, 1, 1, 0.1)
            border.width: 1
        }
        color: "white"
        selectByMouse: true
        focus: true
    }

    ColumnLayout {
        id: prompts
        anchors.top: parent.verticalCenter
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        TextField {
            id: passwordBox
            Layout.minimumHeight: implicitHeight
            Layout.maximumHeight: gridUnit * 10
            Layout.maximumWidth: gridUnit * 16
            Layout.alignment: Qt.AlignHCenter

            background: Rectangle{
                color: "white"
                opacity: 0.2
                radius: 4
                implicitWidth: 250
                implicitHeight: 36
                border.color: Qt.rgba(1, 1, 1, 0.1)
                border.width: 1
            }
            color: "white"
            selectByMouse: true
            focus: true
            echoMode: TextInput.Password
            onAccepted: {
                if (root.loginScreenUiVisible && passwordBox.text.length > 0) {
                    startLogin();
                }
            }

            Keys.onEscapePressed: {
                mainStack.currentItem.forceActiveFocus();
            }

            Keys.onPressed: {
                if(!isOther)
                    passwordBox.forceActiveFocus()
                if (event.key === Qt.Key_Left && !text) {
                    userList.decrementCurrentIndex();
                    event.accepted = true
                }
                if (event.key === Qt.Key_Right && !text) {
                    userList.incrementCurrentIndex();
                    event.accepted = true
                }
            }
            Button{
                id: loginButton
                width: 30
                height: 26
                anchors.right: parent.right
                anchors.rightMargin: 5
                activeFocusOnTab: true
                anchors.verticalCenter: parent.verticalCenter
                contentItem: Image{
                    anchors.fill: parent
                    source: "button_login_normal.png"
                }
                background: Rectangle{
                    anchors.fill: parent
                    radius: 4
                    color: loginButton.hovered || loginButton.activeFocus ?
                               loginButton.down ? Qt.rgba(1, 1, 1, 0.1) : Qt.rgba(1, 1, 1, 0.2) : "transparent"
                }
                onClicked: {
                    if(root.loginScreenUiVisible && passwordBox.text.length > 0)
                        startLogin()
                }
            }
            Component.onCompleted: {
                passwordBox.forceActiveFocus()
            }
        }
        Image {
            id: busyIndicator
            Layout.alignment: Qt.AlignHCenter

            source: "loading.png"; visible: isOn
            NumberAnimation on rotation { running: isOn; from: 0; to: 360; loops: Animation.Infinite; duration: 1200 }
        }
        Label {
            id: notificationsLabel
            Layout.maximumWidth: gridUnit * 16
            Layout.alignment: Qt.AlignHCenter
            Layout.fillWidth: true
            color: "white"
            font.pointSize: fontSize
            visible: !isOn
            horizontalAlignment: Text.AlignHCenter
            wrapMode: Text.WordWrap
        }
        Item {
            Layout.fillHeight: true
        }
    }


}
