import QtQuick 2.2

PathView {
    id: view
    readonly property string selectedUser: currentItem ? currentItem.userName : ""
    readonly property int userItemWidth: gridUnit * 8 + smallSpacing * 2
    readonly property int userItemHeight: gridUnit * 8
    property int modelCount: model.count >= userListModel.disableAvatarsThreshold ?
                                 userListModel.disableAvatarsThreshold : model.count
    implicitWidth: userItemWidth * modelCount
    implicitHeight: userItemHeight

    activeFocusOnTab : true

    signal userSelected

    highlightRangeMode: ListView.StrictlyEnforceRange
    preferredHighlightBegin: 0.5
    preferredHighlightEnd: 0.5
    pathItemCount: modelCount
    path: Path{
        startX: 0
        startY: height/2
        PathLine { x:width/2; y: height/2;}
        PathLine {x:width; y: height/2;}
    }

    delegate: UserDelegate {
        avatarPath: model.icon || ""
        name: {
            var displayName = model.realName || model.name

            if (model.vtNumber === undefined || model.vtNumber < 0) {
                return displayName
            }

            if (!model.session) {
                return i18ndc("plasma_lookandfeel_org.kde.lookandfeel", "Nobody logged in on that session", "Unused")
            }


            var location = ""
            if (model.isTty) {
                location = i18ndc("plasma_lookandfeel_org.kde.lookandfeel", "User logged in on console number", "TTY %1", model.vtNumber)
            } else if (model.displayNumber) {
                location = i18ndc("plasma_lookandfeel_org.kde.lookandfeel", "User logged in on console (X display number)", "on TTY %1 (Display %2)", model.vtNumber, model.displayNumber)
            }

            if (location) {
                return i18ndc("plasma_lookandfeel_org.kde.lookandfeel", "Username (location)", "%1 (%2)", displayName, location)
            }

            return displayName
        }

        userName: model.name

        width:  userItemWidth
        height: userItemHeight

        constrainText: PathView.view.count > 1

        isCurrent: PathView.isCurrentItem

        onClicked: {
            PathView.view.currentIndex = index;
            PathView.view.userSelected();
        }
    }

    Keys.onEscapePressed: view.userSelected()
    Keys.onEnterPressed: view.userSelected()
    Keys.onReturnPressed: view.userSelected()
}
